@@ -48,6 +48,7 @@ describe 'ec2api::keystone::authtoken' do
         is_expected.to contain_ec2api_config('keystone_authtoken/token_cache_time').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_ec2api_config('keystone_authtoken/service_token_roles').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_ec2api_config('keystone_authtoken/service_token_roles_required').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_ec2api_config('keystone_authtoken/service_type').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_ec2api_config('keystone_authtoken/interface').with_value('<SERVICE DEFAULT>')
       end
     end
@@ -91,6 +92,7 @@ describe 'ec2api::keystone::authtoken' do
           :token_cache_time                     => '301',
           :service_token_roles                  => ['service'],
           :service_token_roles_required         => false,
+          :service_type                         => 'identity',
           :interface                            => 'internal',
         })
       end
@@ -129,6 +131,7 @@ describe 'ec2api::keystone::authtoken' do
         is_expected.to contain_ec2api_config('keystone_authtoken/token_cache_time').with_value(params[:token_cache_time])
         is_expected.to contain_ec2api_config('keystone_authtoken/service_token_roles').with_value(params[:service_token_roles])
         is_expected.to contain_ec2api_config('keystone_authtoken/service_token_roles_required').with_value(params[:service_token_roles_required])
+        is_expected.to contain_ec2api_config('keystone_authtoken/service_type').with_value(params[:service_type])
         is_expected.to contain_ec2api_config('keystone_authtoken/interface').with_value(params[:interface])
       end
 
